package com.folmoortiz.expoagenda.repository;

/* se crea una clase singleton para crear una instancia única
  de la base de datos Firebase y recoger todos los métodos de
  I/O requeridos por las vistas */

import android.arch.lifecycle.MutableLiveData;
import android.support.annotation.NonNull;
import android.util.Log;

import com.folmoortiz.expoagenda.model.Evento;
import com.folmoortiz.expoagenda.model.Expositor;
import com.folmoortiz.expoagenda.model.Feria;
import com.folmoortiz.expoagenda.model.Noticia;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.GenericTypeIndicator;
import com.google.firebase.database.ValueEventListener;

import java.util.ArrayList;

public class ExpoAgendaManager {

    // Reference of Firebase object
    private static FirebaseDatabase firebaseDatabase;

    // Lista de eventos de la expo
    private static MutableLiveData<ArrayList<Evento>> listaEventos;
    // Lista de expositores de la expo
    private static MutableLiveData<ArrayList<Expositor>> listaExpositores;
    // Lista de noticias de la expo
    private static MutableLiveData<ArrayList<Noticia>> listaNoticias;
    // Datos de la expo
    private static MutableLiveData<Feria> feria;

    /**
     * Classic Singleton design pattern implementation
     */

    // Class instance
    private static ExpoAgendaManager instance = null;

    private ExpoAgendaManager() {
        firebaseDatabase = FirebaseDatabase.getInstance();
        // Enabling disk persistence allows our app to also keep all of its state even after an app restart
        FirebaseDatabase.getInstance().setPersistenceEnabled(true);
    }

    public static ExpoAgendaManager getInstance() {
        if (instance == null) {
            instance = new ExpoAgendaManager();
        }
        return instance;
    }


    /*******************************/
    /* METODOS DE I/O CON FIREBASE */
    /*******************************/

    // devuelve la info de la feria
    public static MutableLiveData<Feria> getFeria() {
        feria = new MutableLiveData<>();
        DatabaseReference dataBaseFeria = firebaseDatabase.getReference().child("/feria");
        dataBaseFeria.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(@NonNull DataSnapshot dataSnapshot) {
                feria.setValue(dataSnapshot.getValue(Feria.class));
                Log.i("expo", feria.getValue().getDescripcion());
            }

            @Override
            public void onCancelled(@NonNull DatabaseError databaseError) {
                feria = null;
            }
        });
        return feria;
    }

    // devuelve la lista de noticias
    public static MutableLiveData<ArrayList<Noticia>> getListaNoticias() {
        listaNoticias = new MutableLiveData<>();
        final DatabaseReference dataBaseListaNoticias = firebaseDatabase.getReference().child("/noticias");
        dataBaseListaNoticias.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(@NonNull DataSnapshot dataSnapshot) {
                GenericTypeIndicator<ArrayList<Noticia>> genericTypeIndicator = new GenericTypeIndicator<ArrayList<Noticia>>() {};
                listaNoticias.setValue(dataSnapshot.getValue(genericTypeIndicator));
            }

            @Override
            public void onCancelled(@NonNull DatabaseError databaseError) {
                listaNoticias = null;
            }
        });
        return listaNoticias;
    }

    // devuelve la lista de expositores
    public static MutableLiveData<ArrayList<Expositor>> getListaExpositores() {
        listaExpositores = new MutableLiveData<>();
        final DatabaseReference dataBaseListaExpositores = firebaseDatabase.getReference().child("/expositores");
        dataBaseListaExpositores.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(@NonNull DataSnapshot dataSnapshot) {
                GenericTypeIndicator<ArrayList<Expositor>> genericTypeIndicator = new GenericTypeIndicator<ArrayList<Expositor>>() {};
                listaExpositores.setValue(dataSnapshot.getValue(genericTypeIndicator));
            }

            @Override
            public void onCancelled(@NonNull DatabaseError databaseError) {
                listaExpositores = null;
            }
        });
        return listaExpositores;
    }

    // devuelve la lista de eventos
    public static MutableLiveData<ArrayList<Evento>> getListaEventos() {
        listaEventos = new MutableLiveData<>();
        final DatabaseReference dataBaseListaEventos = firebaseDatabase.getReference().child("/eventos");
        dataBaseListaEventos.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(@NonNull DataSnapshot dataSnapshot) {
                GenericTypeIndicator<ArrayList<Evento>> genericTypeIndicator = new GenericTypeIndicator<ArrayList<Evento>>() {};
                listaEventos.setValue(dataSnapshot.getValue(genericTypeIndicator));
            }

            @Override
            public void onCancelled(@NonNull DatabaseError databaseError) {
                listaEventos = null;
            }
        });
        return listaEventos;
    }

}
