package com.folmoortiz.expoagenda.view;

import android.app.ProgressDialog;
import android.arch.lifecycle.Observer;
import android.arch.lifecycle.ViewModelProviders;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Evento;
import com.folmoortiz.expoagenda.viewModel.ListaEventosViewModel;
import java.util.ArrayList;

public class AgendaExpo extends AppCompatActivity {

    private RecyclerView recyclerView;
    private ListaEventosAdapter listaEventosAdapter;
    private ListaEventosViewModel listaEventosViewModel;
    private ProgressDialog dialogo = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_agenda_expo);

        getSupportActionBar().setTitle(R.string.app_name);
        getSupportActionBar().setSubtitle(R.string.subtitle_agenda);

        // formatea un ProgressDialog para la carga de datos
        dialogo = new ProgressDialog(this);
        dialogo.setProgressStyle(0);
        dialogo.setMessage("Consultando al servidor ...");
        dialogo.setCanceledOnTouchOutside(false);
        dialogo.show();

        // inserta el ViewModel e instancia su observador sobre el LiveData de la lista de eventos
        listaEventosViewModel = ViewModelProviders.of(this).get(ListaEventosViewModel.class);
        listaEventosViewModel.getListaEventos().observe(this, new Observer<ArrayList<Evento>>() {
            @Override
            public void onChanged(@Nullable ArrayList<Evento> eventos) {
                inicializaRecyclerView(eventos);
            }
        });
    }

    @Override
    protected void onDestroy() {
        if (dialogo != null)
            if (dialogo.isShowing())
                dialogo.dismiss();

        super.onDestroy();
    }

    // configuracion del recyclerView y su adapter
    public void inicializaRecyclerView(final ArrayList<Evento> eventos) {
        recyclerView = findViewById(R.id.lista_eventos);
        recyclerView.setHasFixedSize(true);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));
        recyclerView.addItemDecoration(new DividerItemDecoration(this, DividerItemDecoration.VERTICAL));

        listaEventosAdapter = new ListaEventosAdapter(this, eventos);
        listaEventosAdapter.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Bundle bundle = new Bundle();
                bundle.putSerializable("evento", eventos.get(recyclerView.getChildAdapterPosition(v)));
                Intent intent = new Intent(getApplicationContext(), DetalleEvento.class);
                intent.putExtras(bundle);
                startActivity(intent);
            }
        });
        recyclerView.setAdapter(listaEventosAdapter);
        dialogo.dismiss();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_principal, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        MenuToolBar menuToolBar = new MenuToolBar();
        try {
            Class claseDestino = Class.forName(getPackageName() + ".view." + menuToolBar.navegaMenu(item));
            startActivity(new Intent(this, claseDestino));
        } catch (ClassNotFoundException e) {
            Log.i("mensaje", e.toString());
        }
        return super.onOptionsItemSelected(item);
    }
}
