package com.folmoortiz.expoagenda.view;

import android.app.ProgressDialog;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.support.constraint.ConstraintLayout;
import android.support.design.widget.Snackbar;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.CompoundButton;
import android.widget.Switch;
import android.widget.TextView;
import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Evento;
import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.MarkerOptions;

public class DetalleEvento extends AppCompatActivity implements OnMapReadyCallback {

    private Evento evento;
    private ProgressDialog dialogo = null;
    private Switch switch_subscripcion;
    private SharedPreferences sharedPreferences;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_detalle_evento);
        final ConstraintLayout constraintLayout = findViewById(R.id.contenedor);

        getSupportActionBar().setTitle(R.string.app_name);
        getSupportActionBar().setSubtitle(R.string.subtitle_agenda);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        // formatea un ProgressDialog para la carga de datos
        dialogo = new ProgressDialog(this);
        dialogo.setProgressStyle(0);
        dialogo.setMessage("Consultando al servidor ...");
        dialogo.setCanceledOnTouchOutside(false);
        dialogo.show();

        // recoge el objeto Evento pasado desde la lista
        Bundle bundle = getIntent().getExtras();
        evento = (Evento) bundle.getSerializable("evento");

        TextView texto_dia_evento = findViewById(R.id.texto_dia_evento);
        texto_dia_evento.setText(formateaFechaEvento("dia"));
        TextView texto_hora_evento = findViewById(R.id.texto_hora_evento);
        texto_hora_evento.setText(formateaFechaEvento("hora"));

        TextView titulo_evento_detalle = findViewById(R.id.titulo_evento_detalle);
        titulo_evento_detalle.setText(evento.getNombre());
        TextView lugar_evento_detalle = findViewById(R.id.lugar_evento_detalle);
        lugar_evento_detalle.setText(evento.getLugar());
        TextView texto_descripcion_evento_detalle = findViewById(R.id.texto_descripcion_evento_detalle);
        texto_descripcion_evento_detalle.setText(evento.getDescripcion());

        // obtiene el fichero SharedPreferences en modo privado
        sharedPreferences = getSharedPreferences("preferences", MODE_PRIVATE);

        // configura la accion del boton de subscribirse al evento
        switch_subscripcion = findViewById(R.id.switch_subscripcion);
        compruebaSubscripcionEvento();
        switch_subscripcion.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                if (isChecked) {
                    gestionaSubscripcion(1);
                    Snackbar.make(
                            constraintLayout,
                            "Evento subscrito. Se ha creado una alarma para avisarle en el día y hora programados",
                            Snackbar.LENGTH_LONG
                    ).show();
                } else {
                    gestionaSubscripcion(0);
                    Snackbar.make(
                            constraintLayout,
                            "Ha desactivado la subscripción al evento. La alarma de aviso ha sido eliminada",
                            Snackbar.LENGTH_LONG
                    ).show();
                }
            }
        });

        // configura el mapa donde tiene lugar el evento
        configurarMapa();
    }

    private void configurarMapa() {
        SupportMapFragment mapFragment = (SupportMapFragment) getSupportFragmentManager().findFragmentById(R.id.mapa);
        mapFragment.getMapAsync(this);
    }

    @Override
    public void onMapReady(GoogleMap googleMap) {
        dialogo.dismiss();

        // Agrega un marcador en el lugar del evento y mueve la camera hasta el lugar
        LatLng lugarEvento = new LatLng(evento.getLatitud(), evento.getLongitud());
        googleMap.addMarker(new MarkerOptions().position(lugarEvento).title("Lugar del evento"));
        googleMap.animateCamera(CameraUpdateFactory.newLatLngZoom(lugarEvento, 15));
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_principal, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        int id = item.getItemId();
        if (id == android.R.id.home) {
            startActivity(new Intent(this, AgendaExpo.class));
        }

        MenuToolBar menuToolBar = new MenuToolBar();
        try {
            Class claseDestino = Class.forName(getPackageName() + ".view." + menuToolBar.navegaMenu(item));
            startActivity(new Intent(this, claseDestino));
        } catch (ClassNotFoundException e) {
            Log.i("mensaje", e.toString());
        }
        return super.onOptionsItemSelected(item);
    }

    // devuelve el dia o la hora de la fecha del evento
    private String formateaFechaEvento(String tipo) {
        String[] fechaItem = evento.getFecha().split("#");
        if (tipo == "dia") {
            String[] arrayDia = fechaItem[0].split("/");
            return arrayDia[0];
        } else {
            return fechaItem[1];
        }
    }

    // comprueba si el evento esta subscrito
    private void compruebaSubscripcionEvento() {
        if (sharedPreferences.contains(evento.getId())) {
            switch_subscripcion.setChecked(true);
            Log.i("prefs", evento.getId());
        }
    }

    // gestiona la subscripcion del evento
    private void gestionaSubscripcion(int tipo) {

        SharedPreferences.Editor editor = sharedPreferences.edit();

        if (tipo == 0) { // elimina la subscripcion

            if (sharedPreferences.contains(evento.getId())) {
                editor.remove(evento.getId());
                editor.apply();
            }

        } else { // subscribe al evento
            if (!sharedPreferences.contains(evento.getId())) {
                // escribe la cadena en SharedPreferences
                editor.putString(evento.getId(), "1");
                editor.apply();
            }
        }
        Log.i("prefs", sharedPreferences.getAll().toString());
    }

}
