package com.folmoortiz.expoagenda.view;

import android.app.ProgressDialog;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.request.RequestOptions;
import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Expositor;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.firebase.storage.FirebaseStorage;
import com.google.firebase.storage.StorageReference;

public class DetalleExpositor extends AppCompatActivity implements View.OnClickListener {

    private Expositor expositor;
    private ImageView logo_expositor;
    private ImageView foto_expositor;
    private ProgressDialog dialogo = null;
    private StorageReference mStorageRef;
    private RequestOptions requestOptions;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_detalle_expositor);

        getSupportActionBar().setTitle(R.string.app_name);
        getSupportActionBar().setSubtitle(R.string.subtitle_expositores);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        // formatea un ProgressDialog para la carga de datos
        dialogo = new ProgressDialog(this);
        dialogo.setProgressStyle(0);
        dialogo.setMessage("Consultando al servidor ...");
        dialogo.setCanceledOnTouchOutside(false);
        dialogo.show();

        // recupera el objeto Expositor pasado desde la lista
        Bundle bundle = getIntent().getExtras();
        expositor = (Expositor) bundle.getSerializable("expositor");

        TextView texto_expositor_nombre = findViewById(R.id.texto_expositor_nombre);
        texto_expositor_nombre.setText(expositor.getNombre());
        TextView texto_expositor_eslogan = findViewById(R.id.texto_expositor_eslogan);
        texto_expositor_eslogan.setText(expositor.getEslogan());
        TextView texto_expositor_descripcion = findViewById(R.id.texto_expositor_descripcion);
        texto_expositor_descripcion.setText(expositor.getDescripcion());

        // datos de contacto del expositor
        TextView contacto_persona = findViewById(R.id.contacto_persona);
        contacto_persona.setText(expositor.getContacto().getPersona());

        TextView contacto_email = findViewById(R.id.contacto_email);
        contacto_email.setText(expositor.getContacto().getEmail());

        TextView contacto_telefono = findViewById(R.id.contacto_telefono);
        contacto_telefono.setText(expositor.getContacto().getTelefono());

        TextView contacto_web = findViewById(R.id.contacto_web);
        contacto_web.setText(expositor.getContacto().getWeb());

        TextView contacto_direccion = findViewById(R.id.contacto_direccion);
        contacto_direccion.setText(expositor.getContacto().getDireccion());

        TextView contacto_cp = findViewById(R.id.contacto_cp);
        contacto_cp.setText(expositor.getContacto().getCp());

        TextView contacto_poblacion = findViewById(R.id.contacto_poblacion);
        contacto_poblacion.setText(expositor.getContacto().getPoblacion());

        TextView contacto_provincia = findViewById(R.id.contacto_provincia);
        contacto_provincia.setText(expositor.getContacto().getProvincia());

        TextView contacto_pais = findViewById(R.id.contacto_pais);
        contacto_pais.setText(expositor.getContacto().getPais());

        // agrega eventos click a los botones de contacto con enlace
        LinearLayout boton_email = findViewById(R.id.boton_email);
        boton_email.setOnClickListener(this);
        LinearLayout boton_telefono = findViewById(R.id.boton_telefono);
        boton_telefono.setOnClickListener(this);
        LinearLayout boton_web = findViewById(R.id.boton_web);
        boton_web.setOnClickListener(this);

        logo_expositor = findViewById(R.id.logo_expositor);
        foto_expositor = findViewById(R.id.foto_expositor);

        // se obtiene la referencia a la carpeta FirebaseStorage
        mStorageRef = FirebaseStorage.getInstance().getReference();

        // Glide es una libreria para descarga optimizada de ficheros;
        // se configura Glide para que guarde la imagen procesada en cache
        requestOptions = new RequestOptions().diskCacheStrategy(DiskCacheStrategy.RESOURCE);

        cargaLogoExpositor();
    }

    // carga el logo del expositor desde FirebaseStorage
    private void cargaLogoExpositor() {

        // descarga las fotos de las noticias desde FirebaseStorage, usando la libreria Glide
        mStorageRef.child("logos").child(expositor.getLogotipo()).getDownloadUrl().addOnSuccessListener(new OnSuccessListener<Uri>() {
            @Override
            public void onSuccess(Uri uri) {
                Glide.with(getApplicationContext())
                        .load(uri)
                        .apply(requestOptions)
                        .into(logo_expositor);

                // una vez cargado el logo, se carga la foto del expositor
                cargaFotoExpositor();
            }
        }).addOnFailureListener(new OnFailureListener() {
            @Override
            public void onFailure(@NonNull Exception e) {
                dialogo.dismiss();
                Toast.makeText(getApplicationContext(), "Error al descargar la imagen", Toast.LENGTH_SHORT).show();
            }
        });
    }

    // carga la foto del expositor
    private void cargaFotoExpositor() {
        mStorageRef.child("expositores").child(expositor.getFotografia()).getDownloadUrl().addOnSuccessListener(new OnSuccessListener<Uri>() {
            @Override
            public void onSuccess(Uri uri) {
                Glide.with(getApplicationContext())
                        .load(uri)
                        .apply(requestOptions)
                        .into(foto_expositor);

                dialogo.dismiss();
            }
        }).addOnFailureListener(new OnFailureListener() {
            @Override
            public void onFailure(@NonNull Exception e) {
                dialogo.dismiss();
                Toast.makeText(getApplicationContext(), "Error al descargar la imagen", Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_principal, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        int id = item.getItemId();
        if (id == android.R.id.home) {
            startActivity(new Intent(this, ExpositoresLista.class));
        }

        MenuToolBar menuToolBar = new MenuToolBar();
        try {
            Class claseDestino = Class.forName(getPackageName() + ".view." + menuToolBar.navegaMenu(item));
            startActivity(new Intent(this, claseDestino));
        } catch (ClassNotFoundException e) {
            Log.i("mensaje", e.toString());
        }
        return super.onOptionsItemSelected(item);
    }

    // recoge los eventos click del contacto
    @Override
    public void onClick(View v) {
        int idBoton = v.getId();

        switch (idBoton) {

            case R.id.boton_email:
                Intent intentEmail = new Intent(Intent.ACTION_SEND);
                intentEmail.setType("message/rfc822");
                intentEmail.putExtra(Intent.EXTRA_EMAIL, new String[]{expositor.getContacto().getEmail()});
                intentEmail.putExtra(Intent.EXTRA_SUBJECT, "Mensaje de " + expositor.getNombre());
                startActivity(Intent.createChooser(intentEmail, "Elija la aplicación"));
                break;

            case R.id.boton_telefono:
                Intent intentoTelefono = new Intent(Intent.ACTION_DIAL, Uri.parse("tel:" + expositor.getContacto().getTelefono()));
                startActivity(intentoTelefono);
                break;

            case R.id.boton_web:
                Intent intentWeb = new Intent(Intent.ACTION_VIEW, Uri.parse(expositor.getContacto().getWeb()));
                startActivity(intentWeb);
                break;
        }
    }
}
