package com.folmoortiz.expoagenda.view;

import android.app.ProgressDialog;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.request.RequestOptions;
import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Noticia;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.firebase.storage.FirebaseStorage;
import com.google.firebase.storage.StorageReference;

public class DetalleNoticia extends AppCompatActivity {

    private Noticia noticia;
    ImageView foto_noticia;
    private ProgressDialog dialogo = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_detalle_noticia);

        getSupportActionBar().setTitle(R.string.app_name);
        getSupportActionBar().setSubtitle(R.string.subtitle_noticias);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        // formatea un ProgressDialog para la carga de datos
        dialogo = new ProgressDialog(this);
        dialogo.setProgressStyle(0);
        dialogo.setMessage("Consultando al servidor ...");
        dialogo.setCanceledOnTouchOutside(false);
        dialogo.show();

        Bundle bundle = getIntent().getExtras();
        noticia = (Noticia) bundle.getSerializable("noticia");

        foto_noticia = findViewById(R.id.foto_noticia);
        TextView text_noticia_titulo = findViewById(R.id.text_noticia_titulo);
        text_noticia_titulo.setText(noticia.getTitulo());
        TextView texto_noticia_fecha = findViewById(R.id.texto_noticia_fecha);
        texto_noticia_fecha.setText(noticia.getFecha());
        TextView texto_noticia_detalle = findViewById(R.id.texto_noticia_detalle);
        texto_noticia_detalle.setText(noticia.getCuerpo());

        cargaFotoNoticia();

    }

    // carga la foto de la noticia desde FirebaseStorage
    private void cargaFotoNoticia() {
        // se obtiene la referencia a la carpeta FirebaseStorage
        StorageReference mStorageRef = FirebaseStorage.getInstance().getReference();

        // Glide es una libreria para descarga optimizada de ficheros;
        // se configura Glide para que guarde la imagen procesada en cache
        final RequestOptions requestOptions = new RequestOptions().diskCacheStrategy(DiskCacheStrategy.RESOURCE);

        // descarga las fotos de las noticias desde FirebaseStorage, usando la libreria Glide
        mStorageRef.child("noticias").child(noticia.getFotografia()).getDownloadUrl().addOnSuccessListener(new OnSuccessListener<Uri>() {
            @Override
            public void onSuccess(Uri uri) {
                Glide.with(getApplicationContext())
                        .load(uri)
                        .apply(requestOptions)
                        .into(foto_noticia);

                dialogo.dismiss();
            }
        }).addOnFailureListener(new OnFailureListener() {
            @Override
            public void onFailure(@NonNull Exception e) {
                dialogo.dismiss();
                Toast.makeText(getApplicationContext(), "Error al descargar la imagen", Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_principal, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        int id = item.getItemId();
        if (id == android.R.id.home) {
            startActivity(new Intent(this, NoticiasLista.class));
        }

        MenuToolBar menuToolBar = new MenuToolBar();
        try {
            Class claseDestino = Class.forName(getPackageName() + ".view." + menuToolBar.navegaMenu(item));
            startActivity(new Intent(this, claseDestino));
        } catch (ClassNotFoundException e) {
            Log.i("mensaje", e.toString());
        }
        return super.onOptionsItemSelected(item);
    }
}
