package com.folmoortiz.expoagenda.view;

import android.app.ProgressDialog;
import android.arch.lifecycle.Observer;
import android.arch.lifecycle.ViewModelProvider;
import android.arch.lifecycle.ViewModelProviders;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;
import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Expositor;
import com.folmoortiz.expoagenda.viewModel.ListaExpositoresViewModel;

import java.util.ArrayList;

public class ExpositoresLista extends AppCompatActivity {

    private RecyclerView recyclerView;
    private ListaExpositoresAdapter listaExpositoresAdapter;
    private ListaExpositoresViewModel listaExpositoresViewModel;
    private ProgressDialog dialogo = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_expositores_lista);

        getSupportActionBar().setTitle(R.string.app_name);
        getSupportActionBar().setSubtitle(R.string.subtitle_expositores);

        // formatea un ProgressDialog para la carga de datos
        dialogo = new ProgressDialog(this);
        dialogo.setProgressStyle(0);
        dialogo.setMessage("Consultando al servidor ...");
        dialogo.setCanceledOnTouchOutside(false);
        dialogo.show();

        // inserta el ViewModel e instancia su observador sobre el LiveData de la lista de expositores
        listaExpositoresViewModel = ViewModelProviders.of(this).get(ListaExpositoresViewModel.class);
        listaExpositoresViewModel.getListaExpositores().observe(this, new Observer<ArrayList<Expositor>>() {
            @Override
            public void onChanged(@Nullable ArrayList<Expositor> expositores) {
                inicializaRecyclerView(expositores);
            }
        });
    }

    // configuracion del recyclerView y su adapter
    public void inicializaRecyclerView(final ArrayList<Expositor> expositores) {
        recyclerView = findViewById(R.id.lista_expositores);
        recyclerView.setHasFixedSize(true);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));
        recyclerView.addItemDecoration(new DividerItemDecoration(this, DividerItemDecoration.VERTICAL));

        listaExpositoresAdapter = new ListaExpositoresAdapter(this, expositores);
        listaExpositoresAdapter.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Bundle bundle = new Bundle();
                bundle.putSerializable("expositor", expositores.get(recyclerView.getChildAdapterPosition(v)));
                Intent intent = new Intent(getApplication(), DetalleExpositor.class);
                intent.putExtras(bundle);
                startActivity(intent);
            }
        });
        recyclerView.setAdapter(listaExpositoresAdapter);
        dialogo.dismiss();
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_principal, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        MenuToolBar menuToolBar = new MenuToolBar();
        try {
            Class claseDestino = Class.forName(getPackageName() + ".view." + menuToolBar.navegaMenu(item));
            startActivity(new Intent(this, claseDestino));
        } catch (ClassNotFoundException e) {
            Log.i("mensaje", e.toString());
        }
        return super.onOptionsItemSelected(item);
    }
}
