package com.folmoortiz.expoagenda.view;

import android.app.Application;
import android.app.ProgressDialog;
import android.arch.lifecycle.Observer;
import android.arch.lifecycle.ViewModelProviders;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.design.widget.TabLayout;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentPagerAdapter;
import android.support.v4.view.ViewPager;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.Toast;

import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Feria;
import com.folmoortiz.expoagenda.viewModel.FeriaViewModel;

public class InformacionExpo extends AppCompatActivity {

    private SectionsPagerAdapter mSectionsPagerAdapter;
    FeriaViewModel feriaViewModel;
    public Feria expo;
    private ProgressDialog dialogo = null;

    /**
     * The {@link ViewPager} that will host this section contents.
     */
    private ViewPager mViewPager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_informacion_expo);

        Toolbar toolbar = findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        getSupportActionBar().setTitle(R.string.app_name);
        getSupportActionBar().setSubtitle(R.string.subtitle_informacion);

        // formatea un ProgressDialog para la carga de datos
        dialogo = new ProgressDialog(this);
        dialogo.setProgressStyle(0);
        dialogo.setMessage("Consultando al servidor ...");
        dialogo.setCanceledOnTouchOutside(false);
        dialogo.show();

        // inserta el ViewModel y obtiene los datos de la Feria
        feriaViewModel = ViewModelProviders.of(this).get(FeriaViewModel.class);

        if (feriaViewModel != null) {
            feriaViewModel.getFeria().observe(this, new Observer<Feria>() {
                @Override
                public void onChanged(@Nullable Feria feria) {
                    expo = feria;
                    Log.i("expo", expo.getContacto().getPersona());

                    // Create the adapter that will return a fragment for each of the three
                    // primary sections of the activity.
                    mSectionsPagerAdapter = new SectionsPagerAdapter(getSupportFragmentManager());

                    // Set up the ViewPager with the sections adapter.
                    mViewPager = findViewById(R.id.container);
                    mViewPager.setAdapter(mSectionsPagerAdapter);

                    TabLayout tabLayout = findViewById(R.id.tabs);
                    mViewPager.addOnPageChangeListener(new TabLayout.TabLayoutOnPageChangeListener(tabLayout));
                    tabLayout.addOnTabSelectedListener(new TabLayout.ViewPagerOnTabSelectedListener(mViewPager));

                    dialogo.dismiss();
                }
            });
        } else {
            Toast.makeText(this, "feriaviewmodel nulo", Toast.LENGTH_SHORT).show();
        }
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_principal, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        MenuToolBar menuToolBar = new MenuToolBar();
        try {
            Class claseDestino = Class.forName(getPackageName() + ".view." + menuToolBar.navegaMenu(item));
            startActivity(new Intent(this, claseDestino));
        } catch (ClassNotFoundException e) {
            Log.i("mensaje", e.toString());
        }
        return super.onOptionsItemSelected(item);
    }


    /**
     * A {@link FragmentPagerAdapter} that returns a fragment corresponding to
     * one of the sections/tabs/pages.
     */
    public class SectionsPagerAdapter extends FragmentPagerAdapter {

        public SectionsPagerAdapter(FragmentManager fm) {
            super(fm);
        }

        @Override
        public Fragment getItem(int position) {
            // getItem is called to instantiate the fragment for the given page.
            switch (position) {
                case 0:
                    Bundle bundle = new Bundle();
                    bundle.putSerializable("expo", expo);
                    InfoFragment infoFragment = new InfoFragment();
                    infoFragment.setArguments(bundle);
                    return infoFragment;
                case 1:
                    Bundle bundleUbicacion = new Bundle();
                    bundleUbicacion.putSerializable("expo", expo);
                    UbicacionFragment ubicacionFragment = new UbicacionFragment();
                    ubicacionFragment.setArguments(bundleUbicacion);
                    return ubicacionFragment;
                case 2:
                    Bundle bundleContacto = new Bundle();
                    bundleContacto.putSerializable("expo", expo);
                    ContactoFragment contactoFragment = new ContactoFragment();
                    contactoFragment.setArguments(bundleContacto);
                    return contactoFragment;
                default:
                    return null;
            }
        }

        @Override
        public int getCount() {
            // Show 3 total pages.
            return 3;
        }
    }
}
