package com.folmoortiz.expoagenda.view;

import android.content.Context;
import android.content.SharedPreferences;
import android.support.annotation.NonNull;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Evento;
import java.util.ArrayList;
import static android.content.Context.MODE_PRIVATE;

public class ListaEventosAdapter extends RecyclerView.Adapter<ListaEventosAdapter.ViewHolder> implements View.OnClickListener {

    private ArrayList<Evento> listaEventos;
    private Context contexto;
    private View.OnClickListener onClickListener;
    private static SharedPreferences sharedPreferences;

    ListaEventosAdapter(Context context, ArrayList<Evento> listaEventos) {
        this.contexto = context;
        this.listaEventos = listaEventos;

        // obtiene el fichero SharedPreferences en modo privado
        // para saber si hay eventos subscritos y marcarlos en la lista
        sharedPreferences = contexto.getSharedPreferences("preferences", MODE_PRIVATE);
    }

    @NonNull
    @Override
    public ListaEventosAdapter.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View view = LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.fila_lista_eventos, viewGroup, false);
        view.setOnClickListener(this);

        return new ViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull final ListaEventosAdapter.ViewHolder viewHolder, int position) {
        viewHolder.texto_dia.setText(formateaFechaEvento(position, "dia"));
        viewHolder.texto_hora.setText(formateaFechaEvento(position, "hora"));
        viewHolder.titulo_evento_lista.setText(listaEventos.get(position).getNombre());
        if(sharedPreferences.contains(listaEventos.get(position).getId())){
            Log.i("adapter", listaEventos.get(position).getId());
            viewHolder.icono_favorito.setImageDrawable(contexto.getResources().getDrawable(R.drawable.icono_star));
        }
    }

    @Override
    public int getItemCount() {
        return listaEventos.size();
    }

    // metodo para enviar el evento click del item
    void setOnClickListener(View.OnClickListener listener) {
        onClickListener = listener;
    }

    @Override
    public void onClick(View v) {
        if (onClickListener != null) {
            onClickListener.onClick(v);
        }
    }

    static class ViewHolder extends RecyclerView.ViewHolder {

        private TextView texto_dia;
        private TextView texto_hora;
        private TextView titulo_evento_lista;
        private ImageView icono_favorito;

        ViewHolder(@NonNull View itemView) {
            super(itemView);

            texto_dia = itemView.findViewById(R.id.texto_dia);
            texto_hora = itemView.findViewById(R.id.texto_hora);
            titulo_evento_lista = itemView.findViewById(R.id.titulo_evento_lista);
            icono_favorito = itemView.findViewById(R.id.icono_favorito);
        }
    }

    // devuelve el dia o la hora de la fecha del evento
    private String formateaFechaEvento(int position, String tipo) {
        String[] fechaItem = listaEventos.get(position).getFecha().split("#");
        if (tipo == "dia") {
            String[] arrayDia = fechaItem[0].split("/");
            return  arrayDia[0];
        } else {
            return fechaItem[1];
        }
    }
}
