package com.folmoortiz.expoagenda.view;

import android.content.Context;
import android.net.Uri;
import android.support.annotation.NonNull;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;
import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.request.RequestOptions;
import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Expositor;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.firebase.storage.FirebaseStorage;
import com.google.firebase.storage.StorageReference;
import java.util.ArrayList;

public class ListaExpositoresAdapter extends RecyclerView.Adapter<ListaExpositoresAdapter.ViewHolder> implements View.OnClickListener {

    private ArrayList<Expositor> listaExpositores;
    private Context contexto;
    private View.OnClickListener onClickListener;
    private StorageReference mStorageRef;
    private RequestOptions requestOptions;

    ListaExpositoresAdapter(Context context, ArrayList<Expositor> listaExpositores) {
        this.contexto = context;
        this.listaExpositores = listaExpositores;

        // Glide es una libreria para descarga optimizada de ficheros;
        // se configura Glide para que guarde la imagen procesada en cache
        requestOptions = new RequestOptions().diskCacheStrategy(DiskCacheStrategy.RESOURCE);

        // se obtiene la referencia a la carpeta FirebaseStorage
        mStorageRef = FirebaseStorage.getInstance().getReference();
    }

    @NonNull
    @Override
    public ListaExpositoresAdapter.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View view = LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.fila_lista_expositores, viewGroup, false);
        view.setOnClickListener(this);
        return new ViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull final ListaExpositoresAdapter.ViewHolder viewHolder, int position) {
        viewHolder.text_nombre.setText(listaExpositores.get(position).getNombre());
        viewHolder.text_eslogan.setText(listaExpositores.get(position).getEslogan());

        // descarga las imagenes de los logotipos de los expositores, desde FirebaseStorage, usando la libreria Glide
        mStorageRef.child("logos").child(listaExpositores.get(position).getLogotipo()).getDownloadUrl().addOnSuccessListener(new OnSuccessListener<Uri>() {
            @Override
            public void onSuccess(Uri uri) {
                Glide.with(contexto)
                        .load(uri)
                        .apply(requestOptions)
                        .into(viewHolder.imagen_expositor_lista);
            }
        }).addOnFailureListener(new OnFailureListener() {
            @Override
            public void onFailure(@NonNull Exception e) {
                Toast.makeText(contexto, "Error al descargar la imagen", Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public int getItemCount() {
        return listaExpositores.size();
    }

    // metodo para enviar el evento click del item
    void setOnClickListener(View.OnClickListener listener) {
        onClickListener = listener;
    }

    @Override
    public void onClick(View v) {
        if (onClickListener != null) {
            onClickListener.onClick(v);
        }
    }

    static class ViewHolder extends RecyclerView.ViewHolder {

        private ImageView imagen_expositor_lista;
        private TextView text_nombre;
        private TextView text_eslogan;

        ViewHolder(@NonNull View itemView) {
            super(itemView);

            imagen_expositor_lista = itemView.findViewById(R.id.imagen_expositor_lista);
            text_nombre = itemView.findViewById(R.id.nombre_expositor_lista);
            text_eslogan = itemView.findViewById(R.id.eslogan_expositor_lista);
        }
    }
}
