package com.folmoortiz.expoagenda.view;

import android.content.Context;
import android.net.Uri;
import android.support.annotation.NonNull;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;
import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.request.RequestOptions;
import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Noticia;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.google.firebase.storage.FirebaseStorage;
import com.google.firebase.storage.StorageReference;
import java.util.ArrayList;

public class ListaNoticiasAdapter extends RecyclerView.Adapter<ListaNoticiasAdapter.ViewHolder> implements View.OnClickListener {

    private ArrayList<Noticia> listaNoticias;
    private Context contexto;
    private View.OnClickListener onClickListener;
    private StorageReference mStorageRef;
    private RequestOptions requestOptions;

    ListaNoticiasAdapter(Context context, ArrayList<Noticia> listaNoticias) {
        this.contexto = context;
        this.listaNoticias = listaNoticias;

        // Glide es una libreria para descarga optimizada de ficheros;
        // se configura Glide para que guarde la imagen procesada en cache y la redondee
        requestOptions = new RequestOptions()
                .apply(RequestOptions.circleCropTransform())
                .diskCacheStrategy(DiskCacheStrategy.RESOURCE);

        // se obtiene la referencia a la carpeta FirebaseStorage
        mStorageRef = FirebaseStorage.getInstance().getReference();
    }

    @NonNull
    @Override
    public ListaNoticiasAdapter.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View view = LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.fila_lista_noticias, viewGroup, false);
        view.setOnClickListener(this);
        return new ViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull final ListaNoticiasAdapter.ViewHolder viewHolder, final int position) {
        viewHolder.titulo_noticia_lista.setText(listaNoticias.get(position).getTitulo());
        viewHolder.cuerpo_noticia_lista.setText(listaNoticias.get(position).getCuerpo());
        viewHolder.fecha_noticia_lista.setText(listaNoticias.get(position).getFecha());

        // descarga las fotos de las noticias desde FirebaseStorage, usando la libreria Glide
        mStorageRef.child("noticias").child(listaNoticias.get(position).getFotografia()).getDownloadUrl().addOnSuccessListener(new OnSuccessListener<Uri>() {
            @Override
            public void onSuccess(Uri uri) {
                Glide.with(contexto)
                        .load(uri)
                        .apply(requestOptions)
                        .into(viewHolder.imagen_noticia_lista);
            }
        }).addOnFailureListener(new OnFailureListener() {
            @Override
            public void onFailure(@NonNull Exception e) {
                Toast.makeText(contexto, "Error al descargar la imagen", Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public int getItemCount() {
        return listaNoticias.size();
    }

    // metodo para enviar el evento click del item
    void setOnClickListener(View.OnClickListener listener) {
        onClickListener = listener;
    }

    @Override
    public void onClick(View v) {
        if (onClickListener != null) {
            onClickListener.onClick(v);
        }
    }

    static class ViewHolder extends RecyclerView.ViewHolder {

        private ImageView imagen_noticia_lista;
        private TextView titulo_noticia_lista;
        private TextView cuerpo_noticia_lista;
        private TextView fecha_noticia_lista;

        ViewHolder(@NonNull View itemView) {
            super(itemView);

            imagen_noticia_lista = itemView.findViewById(R.id.imagen_noticia_lista);
            titulo_noticia_lista = itemView.findViewById(R.id.titulo_noticia_lista);
            cuerpo_noticia_lista = itemView.findViewById(R.id.cuerpo_noticia_lista);
            fecha_noticia_lista = itemView.findViewById(R.id.fecha_noticia_lista);
        }
    }
}
