package com.folmoortiz.expoagenda.view;

import android.app.ProgressDialog;
import android.arch.lifecycle.Observer;
import android.arch.lifecycle.ViewModelProviders;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;

import com.folmoortiz.expoagenda.R;
import com.folmoortiz.expoagenda.model.Noticia;
import com.folmoortiz.expoagenda.viewModel.ListaNoticiasViewModel;
import java.util.ArrayList;

public class NoticiasLista extends AppCompatActivity {

    private RecyclerView recyclerView;
    private ListaNoticiasAdapter listaNoticiasAdapter;
    private ListaNoticiasViewModel listaNoticiasViewModel;
    private ProgressDialog dialogo = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_noticias_lista);

        getSupportActionBar().setTitle(R.string.app_name);
        getSupportActionBar().setSubtitle(R.string.subtitle_noticias);

        // formatea un ProgressDialog para la carga de datos
        dialogo = new ProgressDialog(this);
        dialogo.setProgressStyle(0);
        dialogo.setMessage("Consultando al servidor ...");
        dialogo.setCanceledOnTouchOutside(false);
        dialogo.show();

        // inserta el ViewModel y obtiene la lista de noticias
        listaNoticiasViewModel = ViewModelProviders.of(this).get(ListaNoticiasViewModel.class);
        listaNoticiasViewModel.getListaNoticias().observe(this, new Observer<ArrayList<Noticia>>() {
            @Override
            public void onChanged(@Nullable ArrayList<Noticia> noticias) {
                inicializaRecyclerView(noticias);
            }
        });
    }

    // configuracion del recyclerView y su adapter
    public void inicializaRecyclerView(final ArrayList<Noticia> noticias) {
        recyclerView = findViewById(R.id.lista_noticias);
        recyclerView.setHasFixedSize(true);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));
        recyclerView.addItemDecoration(new DividerItemDecoration(this, DividerItemDecoration.VERTICAL));

        listaNoticiasAdapter = new ListaNoticiasAdapter(this, noticias);
        listaNoticiasAdapter.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Bundle bundle = new Bundle();
                bundle.putSerializable("noticia", noticias.get(recyclerView.getChildAdapterPosition(v)));
                Intent intent = new Intent(getApplication(), DetalleNoticia.class);
                intent.putExtras(bundle);
                startActivity(intent);
            }
        });
        recyclerView.setAdapter(listaNoticiasAdapter);
        dialogo.dismiss();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_principal, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        MenuToolBar menuToolBar = new MenuToolBar();
        try {
            Class claseDestino = Class.forName(getPackageName() + ".view." + menuToolBar.navegaMenu(item));
            startActivity(new Intent(this, claseDestino));
        } catch (ClassNotFoundException e) {
            Log.i("mensaje", e.toString());
        }
        return super.onOptionsItemSelected(item);
    }
}
